@@ -18,7 +18,7 @@
 */
 
 /*
- * $Id: ccid_usb.c 6828 2014-01-21 17:36:11Z rousseau $
+ * $Id: ccid_usb.c 6890 2014-04-24 13:51:03Z rousseau $
  */
 
 #define __CCID_USB__
@@ -219,6 +219,9 @@ status_t OpenUSBByName(unsigned int reader_index, /*@null@*/ char *device)
 	char infofile[FILENAME_MAX];
 #ifndef __APPLE__
 	unsigned int device_vendor, device_product;
+#else
+	/* 100 ms delay */
+	struct timespec sleep_time = { 0, 100 * 1000 * 1000 };
 #endif
 	int interface_number = -1;
 	int i;
@@ -311,6 +314,10 @@ status_t OpenUSBByName(unsigned int reader_index, /*@null@*/ char *device)
 		}
 	}
 
+#ifdef __APPLE__
+	/* give some time to libusb to detect the new USB devices on Mac OS X */
+	nanosleep(&sleep_time, NULL);
+#endif
 	cnt = libusb_get_device_list(ctx, &devs);
 	if (cnt < 0)
 	{
@@ -694,6 +701,7 @@ end:
 		close_libusb_if_needed();
 		if (claim_failed)
 			return STATUS_COMM_ERROR;
+		DEBUG_INFO("Device not found?");
 		return STATUS_NO_SUCH_DEVICE;
 	}
 
@@ -1214,6 +1222,7 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 	ret = libusb_submit_transfer(transfer);
 	if (ret < 0) {
 		libusb_free_transfer(transfer);
+		DEBUG_CRITICAL2("libusb_submit_transfer failed: %d", ret);
 		return ret;
 	}
 
@@ -1231,6 +1240,7 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 				if (libusb_handle_events(ctx) < 0)
 					break;
 			libusb_free_transfer(transfer);
+			DEBUG_CRITICAL2("libusb_handle_events failed: %d", ret);
 			return ret;
 		}
 	}
